@@ -139,6 +139,11 @@ action ical_exit always {Kill ical} {} {
     destroy .
 }
 
+proc ical_close_view {window} {
+    ical_focus_on $window
+    ical_close
+}
+
 action ical_close always {Close ical window} {} {
     # Never try to delete the null view
     if ![string compare [ical_view] ical_null_view] return
@@ -236,6 +241,16 @@ action ical_paste writable {Paste clipboard item} {} {
     run-hook item-create $i
 }
 
+action ical_delete_selection witem {Delete selected text} {} {
+    if ![ical_with_mod_single_item i] return
+    itemwindow_mod junk itemwindow_cut_selection
+}
+
+action ical_insert_selection witem {Delete selected text} {} {
+    if ![ical_with_mod_single_item i] return
+    itemwindow_mod junk itemwindow_insert_selection
+}
+
 action ical_import writable {Parse X selection as an item and add it to calendar} {} {
     if [catch {set sel [selection get]}] {return}
 
