@@ -15,6 +15,7 @@ class charArray;
 class Lexer {
   public:
     Lexer(char const* file);
+    Lexer(charArray*);
     ~Lexer();
 
     /*
@@ -101,7 +102,7 @@ class Lexer {
      * Write "string" to out so that it can be later read back with
      * a call to GetString.  No terminating "]" is output.
      */
-    static void PutString(FILE*, char const* x);
+    static void PutString(charArray*, char const* x);
 
     /*
      * Return current position in file.
