@@ -1,3 +1,4 @@
+# Copyright (c) 1996  by Sanjay Ghemawat
 # Indicate time of day in appointment view
 
 append-hook dayview-startup {view} {
@@ -14,13 +15,13 @@ append-hook dayview-startup {view} {
 proc position_tod {al c} {
     if ![winfo exists $c] {return}
 
-    set t [time split [time now]]
+    set t [ical_time split [ical_time now]]
     set m [expr [lindex $t 0]*60 + [lindex $t 1]]
 
     set y [expr ($m * [$al line_height]) / 30]
     $c coords tod 2m $y 4m $y
 
     # Schedule next firing (at minute boundary)
-    set msec [expr (60 - [time second [time now]])*1000]
+    set msec [expr (60 - [ical_time second [ical_time now]])*1000]
     after $msec position_tod $al $c
 }
