@@ -21,6 +21,7 @@ class DayView {} {
     set ical_view($n) $self
 
     toplevel $n -class Dayview
+    set_geometry {} $n [option get $n geometry Geometry]
 
     set slot(apptlist) [ApptList $n.al $self]
     set slot(notelist) [NoteList $n.nl $self]
@@ -46,13 +47,8 @@ class DayView {} {
 
     wm title $n Calendar
     wm iconname $n ical
-    wm protocol $n WM_DELETE_WINDOW [list ical_close]
-
-    # Set-up geometry
-    set g [option get $n geometry Geometry]
-    if {$g != ""} {
-	catch {wm geometry $n $g}
-    }
+    wm iconbitmap $n ical_icon
+    wm protocol $n WM_DELETE_WINDOW [list ical_close_view $n]
 
     $self set_date [date today]
 
@@ -71,15 +67,17 @@ class DayView {} {
     trigger on change	[list $self change]
     trigger on reconfig	[list $self reconfig]
     trigger on midnight [list $self midnight]
-    trigger on keybind  [list $self rebind]
+    trigger on keybind  [list $self update_menu_accelerators]
     trigger on select   [list $self check_selection]
 
     # Set-up key bindings
-    bindtags $n [list $n IcalCommand Dayview all]
-    $self rebind
+    bindtags $n [list IcalUser $n IcalCommand Dayview all]
 
     # User customization
     ical_with_view $self {run-hook dayview-startup $self}
+
+    # Do the following after user customization to handle user menus as well
+    $self update_menu_accelerators
 }
 
 method DayView destructor {} {
@@ -93,7 +91,7 @@ method DayView destructor {} {
     trigger remove change   [list $self change]
     trigger remove reconfig [list $self reconfig]
     trigger remove midnight [list $self midnight]
-    trigger remove keybind  [list $self rebind]
+    trigger remove keybind  [list $self update_menu_accelerators]
     trigger remove select   [list $self check_selection]
 
     class_kill $slot(apptlist)
@@ -207,7 +205,8 @@ method DayView config_status {} {
 	$slot(window).cal configure -text ""
 	$slot(window).rep configure -text ""
     } else {
-	set disp [ical_title [$item calendar]]
+	set disp ""
+	catch {set disp [ical_title [$item calendar]]}
 
 	if {[$item hilite] == "holiday"} {
 	    set disp [format {%s Holiday} $disp]
@@ -231,18 +230,27 @@ method DayView config_status {} {
     }
 }
 
-# Rebind keys
-method DayView rebind {} {
-    # Update menu accelerator keys
+# Update menu accelerator keys
+method DayView update_menu_accelerators {} {
     global keymap
-    set klist [concat $keymap(command) $keymap(item)]
+    foreach {seq cmd} $keymap(command)	{set key([lindex $cmd 0]) $seq}
+    foreach {seq cmd} $keymap(item)	{set key([lindex $cmd 0]) $seq}
+
+    # Also collect user defined key bindings
+    catch {
+	foreach {seq cmd} [cal option Keybindings] {
+	    set key([lindex $cmd 0]) $seq
+	}
+    }
 
     foreach m [winfo children $slot(window).menu] {
 	set last [$m.m index last]
 	for {set i 0} {$i <= $last} {incr i} {
 	    catch {
 		set act [lindex [$m.m entrycget $i -command] 0]
-		$m.m entryconfig $i -acc "  [key_find_command $act $klist]"
+		set seq {}
+		catch {set seq "  [key_shortform $key($act)]"}
+		$m.m entryconfig $i -acc $seq
 	    }
 	}
     }
@@ -264,17 +272,14 @@ method DayView build_menu {} {
     menu-sep	$b File
     menu-entry	$b File	Exit			{ical_exit}
 
-    menu-entry	$b Edit	Cut			{ical_cut_or_hide}
-    menu-entry	$b Edit	Copy			{ical_copy}
-    menu-entry	$b Edit	Paste			{ical_paste}
-    #menu-sep	$b Edit
-    #menu-entry	$b Edit	{Delete Text}		{ical_delete_selection}
-    #menu-entry	$b Edit	{Insert Text}		{ical_insert_selection}
+    menu-entry	$b Edit	{Cut Item}		{ical_cut_or_hide}
+    menu-entry	$b Edit	{Copy Item}		{ical_copy}
+    menu-entry	$b Edit	{Paste Item}		{ical_paste}
     menu-sep	$b Edit
-    menu-entry	$b Edit	{Import Text}		{ical_import}
+    menu-entry	$b Edit	{Delete Text}		{ical_delete_selection}
+    menu-entry	$b Edit	{Insert Text}		{ical_insert_selection}
     menu-sep	$b Edit
-    menu-entry	$b Edit	{Search Forward}	{ical_search_forward}
-    menu-entry	$b Edit	{Search Backard}	{ical_search_backward}
+    menu-entry	$b Edit	{Import Text as Item}	{ical_import}
 
     menu-bool	$b Item	Todo			{ical_toggle_todo}\
 	dv_state(state:todo)
@@ -290,6 +295,9 @@ method DayView build_menu {} {
     #menu-pull	$b Item	{Move Item To}		{ical_fill_move}
     menu-sep	$b Item
     menu-entry	$b Item	{Properties...}		{ical_edit_item}
+    menu-sep	$b Item
+    menu-entry	$b Item	{Search Forward}	{ical_search_forward}
+    menu-entry	$b Item	{Search Backard}	{ical_search_backward}
 
     menu-entry	$b Repeat {Don't Repeat}	{ical_norepeat}
     menu-sep	$b Repeat
@@ -336,6 +344,10 @@ method DayView build_menu {} {
 
     menu-entry	$b Help	{About Ical}		  {ical_about}
     menu-entry	$b Help {User Guide}		  {ical_help}
+    menu-entry	$b Help {Tcl Interface to Ical}	  {ical_tcl_interface}
+
+    # Move "Help" menu all the way to the right
+    pack configure $b.help -side right
 }
 
 #############################################################################
@@ -368,6 +380,11 @@ proc ical_fill_includes {menu action} {
 proc ical_fill_reminc {menu} {
     $menu delete 0 last
     ical_fill_includes $menu ical_removeinc
+
+    # XXX Work-around Tk 4.1 bug related to empty menu items
+    if ![string compare [$menu index last] none] {
+	$menu add separator
+    }
 }
 
 # effects - Fill move-to-include menu
