@@ -17,6 +17,7 @@
 #	pr_print		Argument for "print"
 #	pr_preview		Argument for "preview"
 #	pr_other		Argument for printing "other # of days"
+#	pr_papersize		{ SetUSLetter, SetA4Paper }
 #
 ######################################################################
 # Minor Changes added by Christopher A. Stoner on 5/30/95            #
@@ -36,6 +37,7 @@ proc pr_make {} {
     if [winfo exists $f] {return}
 
     global pr_done pr_count pr_type pr_save pr_print pr_preview pr_other
+    global pr_papersize
     set pr_other 7
     set pr_count month
     set pr_type  print
@@ -43,8 +45,10 @@ proc pr_make {} {
     set pr_save    cal.ps
     set pr_print   "lpr"
     set pr_preview "ghostview -"
+    set pr_papersize SetUSLetter
     catch {set pr_print   [cal option PrintCommand]}
     catch {set pr_preview [cal option PreviewCommand]}
+    catch {set pr_papersize [cal option PrintPaperSize]}
 
     toplevel $f -class Dialog
     wm title $f Print
@@ -52,6 +56,7 @@ proc pr_make {} {
 
     frame $f.top -class Pane
     frame $f.mid -class Pane
+    frame $f.size -class Pane
 
     frame $f.top.l
     frame $f.top.r
@@ -123,6 +128,17 @@ proc pr_make {} {
     entry $f.mid.entry -width 15
     entry $f.top.r.entry -width 15 -textvariable pr_other
 
+    radiobutton $f.size.letter -text "US Letter" \
+	-anchor w\
+	-relief flat\
+	-variable pr_papersize\
+	-value SetUSLetter
+    radiobutton $f.size.a4 -text "A4 Paper" \
+	-anchor w\
+	-relief flat\
+	-variable pr_papersize\
+	-value SetA4Paper
+
     make_buttons $f.bot 1 {
 	{Cancel		{set pr_done 0}}
 	{Okay		{set pr_done 1}}
@@ -147,7 +163,11 @@ proc pr_make {} {
     pack $f.mid.preview	-side top -expand 1 -fill x
     pack $f.mid.print	-side top -expand 1 -fill x
 
+    pack $f.size.letter -side left -fill x -padx 5m
+    pack $f.size.a4 -side left -fill x -padx 5m
+
     pack $f.top -side top -expand 1 -fill both
+    pack $f.size -side top -fill both
     pack $f.mid -side top -fill both
     pack $f.bot -side bottom -fill both
 
@@ -172,6 +192,7 @@ proc pr_update_entries {} {
 
 proc pr_interact {leader date} {
     global pr_type pr_save pr_preview pr_print pr_done pr_count
+    global pr_papersize
     set f .pr_dialog
 
     # Run dialog
@@ -183,10 +204,11 @@ proc pr_interact {leader date} {
     if ![cal readonly] {
 	cal option PrintCommand   $pr_print
 	cal option PreviewCommand $pr_preview
+	cal option PrintPaperSize $pr_papersize
     }
 
     # Get contents
-    set output [pr_output $date $pr_count]
+    set output [pr_output $date $pr_count $pr_papersize]
 
     switch -exact -- $pr_type {
 	save	{ pr_file $pr_save $output }
@@ -247,7 +269,7 @@ proc pr_outfile {} {
 }
 
 # effects - Return postscript string
-proc pr_output {date count} {
+proc pr_output {date count papersize} {
     if ![string compare $count month] {
 	set str [psmonth $date]
     } else {
@@ -262,6 +284,10 @@ proc pr_output {date count} {
 	set str [psdays $date $count $cols 1]
     }
 
+    
+    set header "$papersize\n%%EndProlog\n%%Page: 1 1\ngsave\n"
+    set trailer "\ngrestore\n%%Trailer\n%%Pages: 1"
+
     global ical
-    return "$ical(psheader)\n%%Page: 1 1\ngsave\n$str\ngrestore\n%%Trailer\n%%Pages: 1"
+    return "$ical(psheader)\n$header$str$trailer"
 }
