@@ -45,10 +45,11 @@ extern int Cmd_CreateAppt	(ClientData, Tcl_Interp*, int, char*[]);
 extern int Cmd_Date		(ClientData, Tcl_Interp*, int, char*[]);
 extern int Cmd_Time		(ClientData, Tcl_Interp*, int, char*[]);
 
-/*
- * Speedup routines.
- */
+/* Speedup routines. */
 extern int Cmd_MonthDays	(ClientData, Tcl_Interp*, int, char*[]);
 extern int Cmd_HiliteLoop	(ClientData, Tcl_Interp*, int, char*[]);
 
+/* Convenience routines */
+extern int Cmd_ExpandFileName	(ClientData, Tcl_Interp*, int, char*[]);
+
 #endif /* _ICAL_H */
