@@ -11,10 +11,7 @@ class ItemListing {} {
     set slot(mainwindow) 0
 
     toplevel .$self -class Listing
-    set g [option get .$self geometry Geometry]
-    if {$g != ""} {
-	catch {wm geometry .$self $g}
-    }
+    set_geometry [ical_leader] .$self [option get .$self geometry Geometry]
 
     wm title .$self "Calendar Items"
     wm iconname .$self "Items"
