@@ -12,9 +12,9 @@ proc item_parse {text {default_date ""}} {
 	set date $d
     }
 
-    if [time extract_range $text start finish j1 j2] {
+    if [ical_time extract_range $text start finish j1 j2] {
 	set type appt
-    } elseif {[time extract_time $text start j1 j2]} {
+    } elseif {[ical_time extract_time $text start j1 j2]} {
 	set finish [expr $start + 60*60]
 	if {$finish > 24*60*60} {set finish [expr 24*60*60]}
 	set type appt
