@@ -3,14 +3,12 @@
 # User Preferences
 
 # Autload support
-proc pref {} {}
-proc Preference-with-name {} {}
-
-class Preference {} {
-    $self reload
+proc pref {type} {
+    # Dispatch to appropriate method
+    return [pref_$type]
 }
 
-method Preference load_common {} {
+proc pref_load_common {} {
     option add *fontFamily		times		startupFile
     option add *fixedFontFamily		courier		startupFile
     option add *Font			fixed		startupFile
@@ -32,22 +30,22 @@ method Preference load_common {} {
     option add *NoteList.Canvas.highlightThickness	0	startupFile
 }
 
-method Preference load_color {} {
-    set fg	[$self findcolor black]
-    set bg	[$self findcolor gray80 white]
-    set wday	[$self findcolor black $fg]
-    set wend	[$self findcolor red $fg]
-    set int	[$self findcolor blue $fg]
-    set wendint	[$self findcolor purple $fg]
+proc pref_load_color {} {
+    set fg	[pref_findcolor black]
+    set bg	[pref_findcolor gray80 white]
+    set wday	[pref_findcolor black $fg]
+    set wend	[pref_findcolor red $fg]
+    set int	[pref_findcolor blue $fg]
+    set wendint	[pref_findcolor purple $fg]
     set line	$fg
     set ifg	$fg
-    set ibg	[$self findcolor gray75 $bg white]
+    set ibg	[pref_findcolor gray75 $bg white]
     set isfg	$fg
-    set isbg	[$self findcolor LightSkyBlue $bg white]
-    set over	[$self findcolor DeepSkyBlue $bg white]
-    set csbg	[$self findcolor khaki $fg]
+    set isbg	[pref_findcolor LightSkyBlue $bg white]
+    set over	[pref_findcolor DeepSkyBlue $bg white]
+    set csbg	[pref_findcolor khaki $fg]
 
-    if [catch {set disabled [$self findcolor gray60]}] {
+    if [catch {set disabled [pref_findcolor gray60]}] {
 	set disabled ""
     }
 
@@ -70,7 +68,7 @@ method Preference load_color {} {
     option add *NoteList.Canvas.BorderWidth	1	startupFile
 }
 
-method Preference load_mono {} {
+proc pref_load_mono {} {
     option add *Foreground		black		startupFile
     option add *Background		white		startupFile
 
@@ -92,22 +90,23 @@ method Preference load_mono {} {
     option add *NoteList.Canvas.BorderWidth	2	startupFile
 }
 
-method Preference reload {} {
+proc pref_init {} {
+    global preference
     option clear
     tcllib_load_options
 
     # Load default options
-    $self load_common
+    pref_load_common
     if [string match *color* [winfo screenvisual .]] {
-	$self load_color
+	pref_load_color
     } else {
-	$self load_mono
+	pref_load_mono
     }
 
-    $self fixfonts
+    pref_fixfonts
 
     # Cache various entries
-    set slot(itemPad)		[winfo pixels . [option get . itemPad Size]]
+    set preference(itemPad)	[winfo pixels . [option get . itemPad Size]]
 
     # Use command-line geometry specification (if any)
     global geometry
@@ -128,9 +127,10 @@ method Preference reload {} {
 }
 
 # Fix fonts in option database
-method Preference fixfonts {} {
+proc pref_fixfonts {} {
+    global preference
     set ff [option get . fontFamily String]
-    set slot(norm_fontfamilies) [concat [list $ff] {
+    set preference(norm_fontfamilies) [concat [list $ff] {
 	times
 	charter
 	{new century schoolbook}
@@ -139,7 +139,7 @@ method Preference fixfonts {} {
     }]
 
     set ff [option get . fixedFontFamily String]
-    set slot(fixed_fontfamilies) [concat [list $ff] {
+    set preference(fixed_fontfamilies) [concat [list $ff] {
 	courier
 	fixed
 	terminal
@@ -163,19 +163,19 @@ method Preference fixfonts {} {
 
     # Normal fonts
     set ff norm_fontfamilies
-    set norm120		[$self findfont medium r $size1 $ff]
-    set norm140		[$self findfont medium r $size2 $ff]
-    set ital140		[$self findfont medium i $size2 $ff]
-    set bold140		[$self findfont bold   r $size2 $ff]
-    set blit140		[$self findfont bold   i $size2 $ff]
-    set norm180		[$self findfont medium r $size3 $ff]
-    set bold180		[$self findfont bold   r $size3 $ff]
-    set norm240		[$self findfont medium r $size4 $ff]
+    set norm120		[pref_findfont medium r $size1 $ff]
+    set norm140		[pref_findfont medium r $size2 $ff]
+    set ital140		[pref_findfont medium i $size2 $ff]
+    set bold140		[pref_findfont bold   r $size2 $ff]
+    set blit140		[pref_findfont bold   i $size2 $ff]
+    set norm180		[pref_findfont medium r $size3 $ff]
+    set bold180		[pref_findfont bold   r $size3 $ff]
+    set norm240		[pref_findfont medium r $size4 $ff]
 
     # Fixed fonts
     set ff fixed_fontfamilies
-    set norm140fixed	[$self findfont medium r $size2 $ff]
-    set bold140fixed	[$self findfont medium r $size2 $ff]
+    set norm140fixed	[pref_findfont medium r $size2 $ff]
+    set bold140fixed	[pref_findfont medium r $size2 $ff]
 
     # Set option database
     option add *weekdayFont		$norm140 startupFile
@@ -219,12 +219,13 @@ method Preference fixfonts {} {
 }
 
 # effects - Find font matching given specification
-method Preference findfont {weight style size ff} {
+proc pref_findfont {weight style size ff} {
+    global preference
     # Try a whole bunch of sizes
     foreach sdelta {0 10 -10 20 -20 30 -30 40 -40} {
 	# Search for this size in families
 	set s [expr $size + $sdelta]
-	foreach family $slot($ff) {
+	foreach family $preference($ff) {
 	    set f "-*-$family-$weight-$style-normal-*-*-$s-*"
 	    if [font_exists $f] {
 		return $f
@@ -237,17 +238,13 @@ method Preference findfont {weight style size ff} {
 }
 
 # effects - Find first legal color in named list and return it.
-method Preference findcolor {args} {
+proc pref_findcolor {args} {
     foreach c $args {
 	if [color_exists $c] {return $c}
     }
     error "could not find any of the following colors: \"[join $args]\""
 }
 
-# To force autoload
-method Preference init {} {
-}
-
 # Methods for obtaining various preferences.
 
 # Return the specified font if it exists, else return fixed.
@@ -259,94 +256,95 @@ proc pref_cf {f} {
     }
 }
 
-method Preference weekdayFont {} {
+proc pref_weekdayFont {} {
     return [pref_cf [option get . weekdayFont Font]]
 }
 
-method Preference weekendFont {} {
+proc pref_weekendFont {} {
     return [pref_cf [option get . weekendFont Font]]
 }
 
-method Preference interestFont {} {
+proc pref_interestFont {} {
     return [pref_cf [option get . interestFont Font]]
 }
 
-method Preference weekendInterestFont {} {
+proc pref_weekendInterestFont {} {
     return [pref_cf [option get . weekendInterestFont Font]]
 }
 
-method Preference itemFont {} {
+proc pref_itemFont {} {
     return [pref_cf [option get . itemFont Font]]
 }
 
-method Preference normFont {} {return [pref_cf [option get . normFont Font]]}
-method Preference boldFont {} {return [pref_cf [option get . boldFont Font]]}
-method Preference italFont {} {return [pref_cf [option get . italFont Font]]}
+proc pref_normFont {} {return [pref_cf [option get . normFont Font]]}
+proc pref_boldFont {} {return [pref_cf [option get . boldFont Font]]}
+proc pref_italFont {} {return [pref_cf [option get . italFont Font]]}
 
-method Preference smallHeadingFont {} {
+proc pref_smallHeadingFont {} {
     return [pref_cf [option get . smallHeadingFont Font]]
 }
 
-method Preference largeHeadingFont {} {
+proc pref_largeHeadingFont {} {
     return [pref_cf [option get . largeHeadingFont Font]]
 }
 
-method Preference weekdayColor {} {
+proc pref_weekdayColor {} {
     return [option get . weekdayColor Foreground]
 }
 
-method Preference weekendColor {} {
+proc pref_weekendColor {} {
     return [option get . weekendColor Foreground]
 }
 
-method Preference interestColor {} {
+proc pref_interestColor {} {
     return [option get . interestColor Foreground]
 }
 
-method Preference weekendInterestColor {} {
+proc pref_weekendInterestColor {} {
     return [option get . weekendInterestColor Foreground]
 }
 
-method Preference itemFg {} {
+proc pref_itemFg {} {
     return [option get . itemFg Foreground]
 }
 
-method Preference itemBg {} {
+proc pref_itemBg {} {
     return [option get . itemBg Background]
 }
 
-method Preference itemSelectFg {} {
+proc pref_itemSelectFg {} {
     return [option get . itemSelectFg Background]
 }
 
-method Preference itemSelectBg {} {
+proc pref_itemSelectBg {} {
     return [option get . itemSelectBg Foreground]
 }
 
-method Preference itemSelectWidth {} {
+proc pref_itemSelectWidth {} {
     return [option get . itemSelectWidth Size]
 }
 
-method Preference itemOverflowColor {} {
+proc pref_itemOverflowColor {} {
     return [option get . itemOverflowColor Foreground]
 }
 
-method Preference itemOverflowStipple {} {
+proc pref_itemOverflowStipple {} {
     return [option get . itemOverflowStipple Bitmap]
 }
 
-method Preference apptLineColor {} {
+proc pref_apptLineColor {} {
     return [option get . apptLineColor Foreground]
 }
 
-method Preference itemPad {} {
-    return $slot(itemPad)
+proc pref_itemPad {} {
+    global preference
+    return $preference(itemPad)
 }
 
-method Preference pollSeconds {} {
+proc pref_pollSeconds {} {
     return [option get . pollSeconds Time]
 }
 
-method Preference saveSeconds {} {
+proc pref_saveSeconds {} {
     return [option get . saveSeconds Time]
 }
