@@ -11,8 +11,8 @@ proc FileSelector {n} {
 
     # Create frame structure
     frame $n -class Inset
-    make_selection_list $n.pbox $n.parents   Parents   left
-    make_selection_list $n.cbox $n.children  Children  right
+    make_selection_list $n.pbox $n.parents   Ancestors  left
+    make_selection_list $n.cbox $n.children  Children   right
     $n.parents configure -width 18 -height 10
     $n.children configure -width 25 -height 10
     entry $n.entry
@@ -31,7 +31,7 @@ proc FileSelector {n} {
     bind $n.parents <ButtonRelease-1> [list _fs_parent $n]
     bind $n.children <ButtonRelease-1> [list _fs_change_file $n]
     bind $n.entry <space> [list _fs_complete $n]
-    bind $n.entry <slash> [list _fs_complete-slash $n]
+    bind $n.entry <slash> [list _fs_complete_slash $n]
 
     # Initialization
     _fs_rescan $n
@@ -213,15 +213,33 @@ proc _fs_complete {n} {
 
     set complete ""
     catch {set complete [lsort [glob -nocomplain $str*]]}
-    if {[llength $complete] == 1} {
+    set len [llength $complete]
+    if {$len == 1} {
 	set str [lindex $complete 0]
     }
 
     fs_goto $n $str
+    if {$len > 0} {
+	_fs_scroll_child $n [file tail [lindex $complete 0]]
+    }
+
     return -code break
 }
 
-proc _fs_complete-slash {n} {
+# Scroll the child box to place strings that match "str" near the front
+proc _fs_scroll_child {n str} {
+    set clist [$n.children get 0 end]
+    set i 0
+    foreach entry $clist {
+	if {[string compare $entry $str] >= 0} {
+	    $n.children see $i
+	    break
+	}
+	incr i
+    }
+}
+
+proc _fs_complete_slash {n} {
     tkEntryInsert $n.entry /
     fs_goto $n [$n.entry get]
     return -code break
