@@ -6,9 +6,6 @@
 #	key_shortform <seq>
 #		Return short-form of key sequence
 #
-#	key_find_command <cmd> <keymap>
-#		Return short-form of key sequence bound to <cmd>
-#
 # Lower-Level Exported Procedures
 #
 # keyentry <widget>			; Create key sequence entry widget
@@ -56,18 +53,6 @@ proc key_shortform {seq} {
     return $seq
 }
 
-# A key map is specified as a list of pairs <key, string>.
-
-# effects Return short form of first binding for <command>
-proc key_find_command {cmd keymap} {
-    foreach b $keymap {
-	if ![string compare [lindex $b 1] $cmd] {
-	    return [key_shortform [lindex $b 0]]
-	}
-    }
-    return ""
-}
-
 #############################################################################
 # Internal procedures
 
