@@ -1,3 +1,4 @@
+# Copyright (c) 1996  by Sanjay Ghemawat
 #############################################################################
 # Menu operations
 #
@@ -51,7 +52,7 @@ proc menu-pull {menubar title label postcommand} {
     set i [$menu index last]
     set cascade $menu.submenu$i
     set cmd [concat $postcommand [list $cascade]]
-    menu $cascade -postcommand $cmd
+    menu $cascade -postcommand $cmd -tearoff 0
 
     $menu add cascade -label $label -menu $cascade -command $cmd
 }
