@@ -40,24 +40,26 @@ proc before_proc {proc code} {
 
 #### Special options ####
 proc tcllib_load_options {} {
-    option add *Pane.BorderWidth	1	startupFile
+    if [string match *color* [winfo screenvisual .]] {
+	set small_bd 1
+	set big_bd 2
+    } else {
+	set small_bd 2
+	set big_bd 3
+    }
+
+    option add *Inset.BorderWidth $big_bd startupFile
+    foreach spec {
+	Pane Entry Scrollbar Button Checkbutton Radiobutton Menubutton Menu
+    } {
+	option add *$spec.BorderWidth $small_bd startupFile
+    }
+
     option add *Pane.Relief		raised	startupFile
-
-    option add *Inset.BorderWidth	2	startupFile
     option add *Inset.Relief		groove	startupFile
-
-    option add *Entry.BorderWidth	1	startupFile
     option add *Entry.Relief		sunken	startupFile
-
-    option add *Scrollbar.BorderWidth	1	startupFile
     option add *Scrollbar.Relief	raised	startupFile
-
-    option add *Button.BorderWidth	1	startupFile
     option add *Button.padX		1m	startupFile
-    option add *Checkbutton.BorderWidth	1	startupFile
-    option add *Radiobutton.BorderWidth	1	startupFile
-    option add *Menubutton.BorderWidth	1	startupFile
-    option add *Menu.BorderWidth	1	startupFile
 }
 
 # effects Make frame containing buttons.
@@ -92,6 +94,27 @@ proc make_buttons {frame default spec} {
     }
 }
 
+# Set geometry so that toplevel shows up in same virtual window as leader 
+proc set_geometry {leader w g} {
+    if ![regexp {^([+-])([0-9]+)([+-])([0-9]+)$} $g junk sx x sy y] {
+	return
+    }
+
+    if ![string compare $sx -] {
+	set x [expr [winfo screenwidth $w] - $x]
+    }
+    if ![string compare $sy -] {
+	set y [expr [winfo screenheight $w] - $y]
+    }
+
+    if ![string compare $leader {}] {
+	set leader $w
+    }
+    set x [expr $x - [winfo vrootx $leader]]
+    set y [expr $y - [winfo vrooty $leader]]
+    wm geometry $w +$x+$y
+}
+
 #############################################################################
 # Dialog Interaction Mechanism
 #
@@ -108,18 +131,24 @@ proc make_buttons {frame default spec} {
 proc dialog_run {leader window var {focuswin ""}} {
     global $var
 
+    # Wait for window geometry to be computed if possible
+    update idletasks
+
     # Center window over leader
     if {$leader == {}} {
 	set x [expr ([winfo screenwidth $window]-[winfo reqwidth $window])/2]
 	set y [expr ([winfo screenheight $window]-[winfo reqheight $window])/2]
+	set_geometry $leader $window +$x+$y
     } else {
-	set x [expr [winfo rootx $leader]+[winfo width $leader]/2]
-	set y [expr [winfo rooty $leader]+[winfo height $leader]/2]
+	set lx [expr [winfo rootx $leader] + [winfo vrootx $leader]]
+	set ly [expr [winfo rooty $leader] + [winfo vrooty $leader]]
+	set x [expr $lx+[winfo width $leader]/2]
+	set y [expr $ly+[winfo height $leader]/2]
 	set x [expr $x-[winfo reqwidth $window]/2]
 	set y [expr $y-[winfo reqheight $window]/2]
+	wm geometry $window +$x+$y
     }
 
-    wm geometry $window +$x+$y
     wm transient $window $leader
     wm deiconify $window
 
@@ -127,7 +156,7 @@ proc dialog_run {leader window var {focuswin ""}} {
     set oldfocus [focus]
     catch {grab set $window}
     focus $focuswin
-    tkwait variable $var
+    vwait $var
     grab release $window
     catch {focus $oldfocus}
     wm withdraw $window
@@ -135,41 +164,7 @@ proc dialog_run {leader window var {focuswin ""}} {
 }
 
 #############################################################################
-# Icon operations
-#
-# Exported Global Variables
-#
-#    icon_path		List of icon directories.
-#
-# Commands
-#
-#    icon <name>	Search for icon with specified <name> and
-#			return specification suitable as an argument
-#			to a -bitmap option.  Raises error if icon not
-#			found.
-#
-# Hidden global variables
-#
-#	_icons		Cache of icons already searched for.
-
-catch {unset _icons}
-
-proc icon {name} {
-    global icon_path _icons
-
-    if ![catch {set result $_icons($name)}] {
-	return $result
-    }
-
-    # Search for icon
-    foreach dir $icon_path {
-	if [file readable "$dir/$name"] {
-	    set _icons($name) "@$dir/$name"
-	    return "@$dir/$name"
-	}
-    }
-    error "no icon $name"
-}
+# Font/color query routines
 
 # effects -  Return width of "text" in "font".  Add "pad" on each side.
 proc text_width {font text {pad 0}} {
