@@ -6,25 +6,6 @@
 //
 // See "htable.h" for macros that should be defined before including this.
 
-// Check that all of the macros are defined
-#ifndef HTABLE
-#error macro HTABLE not defined for hash table instantiation.
-#endif
-#ifndef HKEY
-#error macro HKEY not defined for hash table instantiation.
-#endif
-#ifndef HASHER
-#error macro HASHER not defined for hash table instantiation.
-#endif
-
-#ifndef HTABLEREP
-#ifdef HVAL
-#define HTABLEREP SplitTable2<HKEY,HVAL>
-#else
-#define HTABLEREP SplitTable1<HKEY>
-#endif
-#endif
-
 // Some static data/functions
 #ifndef HTABLE_STATICS
 #define HTABLE_STATICS
@@ -129,11 +110,11 @@ unsigned int HTABLE::find_index(HKEY key) const {
 		index = (index + 1) & msk;
 		if (tbl->is_empty(index)) {
 		    return del_index;
-		} else if (tbl->is_full(index) && (tbl->key(index) == key)) {
+		} else if (tbl->is_full(index) && HEQUAL(tbl->key(index),key)){
 		    return index;
 		}
 	    }
-	} else if (tbl->key(index) == key) {
+	} else if (HEQUAL(tbl->key(index), key)) {
 	    return index;
 	}
 	index = (index + 1) & msk;
@@ -321,7 +302,7 @@ void HTABLE::check() const {
 	if (!table->is_full(i)) continue;
 	for (j = i+1; j < tsize; j++) {
 	    if (!table->is_full(j)) continue;
-	    assert(! (table->key(i) == table->key(j)));
+	    assert(! HEQUAL(table->key(i), table->key(j)));
 	}
     }
 
@@ -431,10 +412,3 @@ void HTABLE::Elements::del() {
     t->delcount++;
     t->table->kill(index);
 }
-
-// Remove the controlling macros now
-#undef HTABLE
-#undef HKEY
-#undef HVAL
-#undef HASHER
-#undef HTABLEREP
