@@ -118,7 +118,7 @@ class HashMap {								      \
      */									      \
 									      \
   private:								      \
-    friend HashMap##_Bindings;						      \
+    friend class HashMap##_Bindings;					      \
 									      \
     enum Typ { empty, occupied, obsolete };				      \
 									      \
