@@ -103,7 +103,7 @@ class HashSet {								      \
      * effects  - Check various rep invariants.  Die on error.		      \
      */									      \
   private:								      \
-    friend HashSet##_Elements;						      \
+    friend class HashSet##_Elements;					      \
 									      \
     enum Typ { empty, occupied, obsolete };				      \
 									      \
